@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2015 Daniel Vrátil <dvratil@kde.org>
+    SPDX-FileCopyrightText: 2015 Daniel Vrátil <dvratil@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KMANAGESIEVE_SESSIONTHREAD_P_H
@@ -22,9 +9,11 @@
 
 #include <QObject>
 #include <QUrl>
+#include <memory>
 
 #include <KIO/Global>
-#include <KTcpSocket>
+#include <QSslSocket>
+#include <KSslErrorUiData>
 
 #include "sasl-common.h"
 #include "response.h"
@@ -54,7 +43,7 @@ public:
 
 Q_SIGNALS:
     void responseReceived(const KManageSieve::Response &response, const QByteArray &data);
-    void error(const QString &error);
+    void error(int errorCode, const QString &error);
     void authenticationDone();
     void sslDone();
     void sslError(const KSslErrorUiData &data);
@@ -81,11 +70,12 @@ private:
     bool saslInteract(void *in);
     bool saslClientStep(const QByteArray &challenge);
     void sslResult(bool encrypted);
+    void handleSaslAuthError();
 
 private:
     Q_DISABLE_COPY(SessionThread)
     Session *m_session = nullptr;
-    KTcpSocket *m_socket = nullptr;
+    std::unique_ptr<QSslSocket> m_socket;
 
     QUrl m_url;
 
@@ -94,7 +84,7 @@ private:
 
     QByteArray m_data;
     Response m_lastResponse;
-    qint64 m_pendingQuantity;
+    qint64 m_pendingQuantity = -1;
 
     QTimer *m_sslCheck = nullptr;
 };
