@@ -1,15 +1,9 @@
 /*  -*- c++ -*-
     sievejob.h
 
-    KMail, the KDE mail client.
-    Copyright (c) 2002 Marc Mutz <mutz@kde.org>
+    SPDX-FileCopyrightText: 2002 Marc Mutz <mutz@kde.org>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License,
-    version 2.0, as published by the Free Software Foundation.
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software Foundation,
-    Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
+    SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "sievejob.h"
@@ -17,7 +11,6 @@
 #include "session.h"
 
 #include "kmanagersieve_debug.h"
-#include <QUrl>
 #include <KLocalizedString>
 #include <QPointer>
 
@@ -114,9 +107,6 @@ void SieveJob::Private::run(Session *session)
         session->sendData(encodedData);
         break;
     }
-
-    default:
-        Q_ASSERT(false);
     }
 }
 
@@ -231,8 +221,6 @@ bool SieveJob::Private::handleResponse(const Response &response, const QByteArra
         run(sessionForUrl(mUrl));
         return false;
     }
-
-    return true;
 }
 
 void SieveJob::Private::killed()
@@ -303,7 +291,7 @@ SieveJob *SieveJob::put(const QUrl &destination, const QString &script, bool mak
 
     commands.push(Private::Put);
 
-    SieveJob *job = new SieveJob;
+    auto *job = new SieveJob;
     job->d->mUrl = destination;
     job->d->mScript = script;
     job->d->mCommands = commands;
@@ -318,7 +306,7 @@ SieveJob *SieveJob::get(const QUrl &source)
     commands.push(Private::Get);
     commands.push(Private::SearchActive);
 
-    SieveJob *job = new SieveJob;
+    auto *job = new SieveJob;
     job->d->mUrl = source;
     job->d->mCommands = commands;
 
@@ -331,7 +319,7 @@ SieveJob *SieveJob::list(const QUrl &source)
     QStack<Private::Command> commands;
     commands.push(Private::List);
 
-    SieveJob *job = new SieveJob;
+    auto *job = new SieveJob;
     job->d->mUrl = source;
     job->d->mCommands = commands;
 
@@ -344,7 +332,7 @@ SieveJob *SieveJob::del(const QUrl &url)
     QStack<Private::Command> commands;
     commands.push(Private::Delete);
 
-    SieveJob *job = new SieveJob;
+    auto *job = new SieveJob;
     job->d->mUrl = url;
     job->d->mCommands = commands;
 
@@ -356,7 +344,7 @@ SieveJob *SieveJob::deactivate(const QUrl &url)
 {
     QStack<Private::Command> commands;
     commands.push(Private::Deactivate);
-    SieveJob *job = new SieveJob;
+    auto *job = new SieveJob;
     job->d->mUrl = url;
     job->d->mCommands = commands;
 
@@ -369,7 +357,7 @@ SieveJob *SieveJob::rename(const QUrl &url, const QString &newName)
     QStack<Private::Command> commands;
     commands.push(Private::Rename);
 
-    SieveJob *job = new SieveJob;
+    auto *job = new SieveJob;
     job->d->mUrl = url;
     job->d->mNewName = newName;
     job->d->mCommands = commands;
@@ -383,7 +371,7 @@ SieveJob *SieveJob::check(const QUrl &url, const QString &script)
     QStack<Private::Command> commands;
     commands.push(Private::Check);
 
-    SieveJob *job = new SieveJob;
+    auto *job = new SieveJob;
     job->d->mUrl = url;
     job->d->mScript = script;
     job->d->mCommands = commands;
@@ -397,7 +385,7 @@ SieveJob *SieveJob::activate(const QUrl &url)
     QStack<Private::Command> commands;
     commands.push(Private::Activate);
 
-    SieveJob *job = new SieveJob;
+    auto *job = new SieveJob;
     job->d->mUrl = url;
     job->d->mCommands = commands;
 
