@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveactionaddheader.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
@@ -39,11 +26,11 @@ SieveActionAddHeader::SieveActionAddHeader(SieveEditorGraphicalModeWidget *sieve
 QWidget *SieveActionAddHeader::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
-    QGridLayout *grid = new QGridLayout;
-    grid->setContentsMargins(0, 0, 0, 0);
+    auto *grid = new QGridLayout;
+    grid->setContentsMargins({});
     w->setLayout(grid);
 
-    SelectAddHeaderPositionCombobox *combo = new SelectAddHeaderPositionCombobox;
+    auto *combo = new SelectAddHeaderPositionCombobox;
     combo->setObjectName(QStringLiteral("selectposition"));
     connect(combo, &SelectAddHeaderPositionCombobox::valueChanged, this, &SieveActionAddHeader::valueChanged);
     grid->addWidget(combo, 0, 0);
@@ -51,7 +38,7 @@ QWidget *SieveActionAddHeader::createParamWidget(QWidget *parent) const
     QLabel *lab = new QLabel(i18n("header:"));
     grid->addWidget(lab, 0, 1);
 
-    QLineEdit *headerEdit = new QLineEdit;
+    auto *headerEdit = new QLineEdit;
     connect(headerEdit, &QLineEdit::textChanged, this, &SieveActionAddHeader::valueChanged);
     headerEdit->setObjectName(QStringLiteral("headeredit"));
     grid->addWidget(headerEdit, 0, 2);
@@ -59,7 +46,7 @@ QWidget *SieveActionAddHeader::createParamWidget(QWidget *parent) const
     lab = new QLabel(i18n("value:"));
     grid->addWidget(lab, 1, 1);
 
-    QLineEdit *valueEdit = new QLineEdit;
+    auto *valueEdit = new QLineEdit;
     connect(valueEdit, &QLineEdit::textChanged, this, &SieveActionAddHeader::valueChanged);
     valueEdit->setObjectName(QStringLiteral("valueedit"));
     grid->addWidget(valueEdit, 1, 2);
@@ -67,20 +54,20 @@ QWidget *SieveActionAddHeader::createParamWidget(QWidget *parent) const
     return w;
 }
 
-bool SieveActionAddHeader::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
+void SieveActionAddHeader::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
 {
     int index = 0;
     while (element.readNextStartElement()) {
         const QStringRef tagName = element.name();
         if (tagName == QLatin1String("tag")) {
-            SelectAddHeaderPositionCombobox *combo = w->findChild<SelectAddHeaderPositionCombobox *>(QStringLiteral("selectposition"));
+            auto *combo = w->findChild<SelectAddHeaderPositionCombobox *>(QStringLiteral("selectposition"));
             combo->setCode(AutoCreateScriptUtil::tagValue(element.readElementText()), name(), error);
         } else if (tagName == QLatin1String("str")) {
             if (index == 0) {
-                QLineEdit *edit = w->findChild<QLineEdit *>(QStringLiteral("headeredit"));
+                auto *edit = w->findChild<QLineEdit *>(QStringLiteral("headeredit"));
                 edit->setText(element.readElementText());
             } else if (index == 1) {
-                QLineEdit *value = w->findChild<QLineEdit *>(QStringLiteral("valueedit"));
+                auto *value = w->findChild<QLineEdit *>(QStringLiteral("valueedit"));
                 value->setText(AutoCreateScriptUtil::quoteStr(element.readElementText()));
             } else {
                 tooManyArguments(tagName, index, 2, error);
@@ -98,8 +85,6 @@ bool SieveActionAddHeader::setParamWidgetValue(QXmlStreamReader &element, QWidge
             qCDebug(LIBKSIEVE_LOG) << "SieveActionAddHeader::setParamWidgetValue unknown tag " << tagName;
         }
     }
-
-    return true;
 }
 
 QString SieveActionAddHeader::code(QWidget *w) const
