@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveactionvacation.h"
 #include "editor/sieveeditorutil.h"
@@ -44,13 +31,13 @@ SieveActionVacation::SieveActionVacation(SieveEditorGraphicalModeWidget *sieveGr
 QWidget *SieveActionVacation::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
-    QGridLayout *grid = new QGridLayout;
-    grid->setContentsMargins(0, 0, 0, 0);
+    auto *grid = new QGridLayout;
+    grid->setContentsMargins({});
     w->setLayout(grid);
 
     QLabel *lab = nullptr;
     if (mHasVacationSecondsSupport) {
-        SelectVacationComboBox *vacation = new SelectVacationComboBox;
+        auto *vacation = new SelectVacationComboBox;
         vacation->setObjectName(QStringLiteral("vacationcombobox"));
         connect(vacation, &SelectVacationComboBox::valueChanged, this, &SieveActionVacation::valueChanged);
         grid->addWidget(vacation, 0, 0);
@@ -59,7 +46,7 @@ QWidget *SieveActionVacation::createParamWidget(QWidget *parent) const
         grid->addWidget(lab, 0, 0);
     }
 
-    QSpinBox *day = new QSpinBox;
+    auto *day = new QSpinBox;
     day->setMinimum(1);
     day->setMaximum(999);
     day->setObjectName(QStringLiteral("day"));
@@ -69,7 +56,7 @@ QWidget *SieveActionVacation::createParamWidget(QWidget *parent) const
     lab = new QLabel(i18n("Message subject:"));
     grid->addWidget(lab, 1, 0);
 
-    QLineEdit *subject = new QLineEdit;
+    auto *subject = new QLineEdit;
     subject->setObjectName(QStringLiteral("subject"));
     connect(subject, &QLineEdit::textChanged, this, &SieveActionVacation::valueChanged);
     grid->addWidget(subject, 1, 1);
@@ -86,7 +73,7 @@ QWidget *SieveActionVacation::createParamWidget(QWidget *parent) const
     lab = new QLabel(i18n("Vacation reason:"));
     grid->addWidget(lab, 3, 0);
 
-    MultiLineEdit *text = new MultiLineEdit;
+    auto *text = new MultiLineEdit;
     connect(text, &MultiLineEdit::valueChanged, this, &SieveActionVacation::valueChanged);
     text->setObjectName(QStringLiteral("text"));
     grid->addWidget(text, 3, 1);
@@ -94,7 +81,7 @@ QWidget *SieveActionVacation::createParamWidget(QWidget *parent) const
     return w;
 }
 
-bool SieveActionVacation::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
+void SieveActionVacation::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
 {
     while (element.readNextStartElement()) {
         const QStringRef tagName = element.name();
@@ -102,7 +89,7 @@ bool SieveActionVacation::setParamWidgetValue(QXmlStreamReader &element, QWidget
             const QString tagValue = element.readElementText();
             if (tagValue == QLatin1String("seconds")) {
                 if (mHasVacationSecondsSupport) {
-                    SelectVacationComboBox *vacationcombobox = w->findChild<SelectVacationComboBox *>(QStringLiteral("vacationcombobox"));
+                    auto *vacationcombobox = w->findChild<SelectVacationComboBox *>(QStringLiteral("vacationcombobox"));
                     vacationcombobox->setCode(AutoCreateScriptUtil::tagValue(tagValue), name(), error);
                 } else {
                     serverDoesNotSupportFeatures(QStringLiteral("seconds"), error);
@@ -110,7 +97,7 @@ bool SieveActionVacation::setParamWidgetValue(QXmlStreamReader &element, QWidget
             } else if (tagValue == QLatin1String("days")) {
                 //Nothing wait num tag for it.
             } else if (tagValue == QLatin1String("addresses")) {
-                AbstractSelectEmailLineEdit *addresses = w->findChild<AbstractSelectEmailLineEdit *>(QStringLiteral("addresses"));
+                auto *addresses = w->findChild<AbstractSelectEmailLineEdit *>(QStringLiteral("addresses"));
                 if (element.readNextStartElement()) {
                     const QStringRef textElementTagName = element.name();
                     if (textElementTagName == QLatin1String("str")) {
@@ -120,17 +107,17 @@ bool SieveActionVacation::setParamWidgetValue(QXmlStreamReader &element, QWidget
                     }
                 }
             } else if (tagValue == QLatin1String("subject")) {
-                QLineEdit *subject = w->findChild<QLineEdit *>(QStringLiteral("subject"));
+                auto *subject = w->findChild<QLineEdit *>(QStringLiteral("subject"));
                 subject->setText(AutoCreateScriptUtil::strValue(element));
             } else {
                 unknownTagValue(tagValue, error);
                 qCDebug(LIBKSIEVE_LOG) << "SieveActionVacation::setParamWidgetValue unknown tagValue :" << tagValue;
             }
         } else if (tagName == QLatin1String("num")) {
-            QSpinBox *day = w->findChild<QSpinBox *>(QStringLiteral("day"));
+            auto *day = w->findChild<QSpinBox *>(QStringLiteral("day"));
             day->setValue(element.readElementText().toInt());
         } else if (tagName == QLatin1String("str")) {
-            MultiLineEdit *text = w->findChild<MultiLineEdit *>(QStringLiteral("text"));
+            auto *text = w->findChild<MultiLineEdit *>(QStringLiteral("text"));
             text->setPlainText(element.readElementText());
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
@@ -143,8 +130,6 @@ bool SieveActionVacation::setParamWidgetValue(QXmlStreamReader &element, QWidget
             qCDebug(LIBKSIEVE_LOG) << " SieveActionVacation::setParamWidgetValue unknown tagName " << tagName;
         }
     }
-
-    return true;
 }
 
 QString SieveActionVacation::code(QWidget *w) const
