@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "sieveactionwidgetlister.h"
@@ -113,7 +100,7 @@ void SieveActionWidget::generatedScript(QString &script, QStringList &required,
 void SieveActionWidget::initWidget()
 {
     mLayout = new QGridLayout(this);
-    mLayout->setContentsMargins(0, 0, 0, 0);
+    mLayout->setContentsMargins({});
 
     mComboBox = new QComboBox;
     mComboBox->setEditable(false);
@@ -267,7 +254,7 @@ void SieveActionWidget::setLocaleVariable(const SieveGlobalVariableActionWidget:
     if (index != -1) {
         mComboBox->setCurrentIndex(index);
         slotActionChanged(index);
-        KSieveUi::SieveActionSetVariable *localVar = qobject_cast<KSieveUi::SieveActionSetVariable *>(mActionList.at(index));
+        auto *localVar = qobject_cast<KSieveUi::SieveActionSetVariable *>(mActionList.at(index));
         if (localVar) {
             localVar->setLocalVariable(this, var);
         }
@@ -336,7 +323,7 @@ void SieveActionWidgetLister::updateAddRemoveButton()
     QList<QWidget *>::ConstIterator wIt = widgetList.constBegin();
     QList<QWidget *>::ConstIterator wEnd = widgetList.constEnd();
     for (; wIt != wEnd; ++wIt) {
-        SieveActionWidget *w = qobject_cast<SieveActionWidget *>(*wIt);
+        auto *w = qobject_cast<SieveActionWidget *>(*wIt);
         w->updateAddRemoveButton(addButtonEnabled, removeButtonEnabled);
     }
 }
@@ -347,7 +334,7 @@ void SieveActionWidgetLister::generatedScript(QString &script, QStringList &requ
     QList<QWidget *>::ConstIterator wIt = widgetList.constBegin();
     QList<QWidget *>::ConstIterator wEnd = widgetList.constEnd();
     for (; wIt != wEnd; ++wIt) {
-        SieveActionWidget *w = qobject_cast<SieveActionWidget *>(*wIt);
+        auto *w = qobject_cast<SieveActionWidget *>(*wIt);
         w->generatedScript(script, requireModules, onlyActions, inForEveryPartLoop);
     }
 }
@@ -362,7 +349,7 @@ void SieveActionWidgetLister::reconnectWidget(SieveActionWidget *w)
 void SieveActionWidgetLister::clearWidget(QWidget *aWidget)
 {
     if (aWidget) {
-        SieveActionWidget *widget = static_cast<SieveActionWidget *>(aWidget);
+        auto *widget = static_cast<SieveActionWidget *>(aWidget);
         widget->clear();
     }
     Q_EMIT valueChanged();
@@ -370,7 +357,7 @@ void SieveActionWidgetLister::clearWidget(QWidget *aWidget)
 
 QWidget *SieveActionWidgetLister::createWidget(QWidget *parent)
 {
-    SieveActionWidget *w = new SieveActionWidget(mSieveGraphicalModeWidget, parent);
+    auto *w = new SieveActionWidget(mSieveGraphicalModeWidget, parent);
     reconnectWidget(w);
     return w;
 }
@@ -382,7 +369,7 @@ int SieveActionWidgetLister::actionNumber() const
 
 void SieveActionWidgetLister::loadLocalVariable(const SieveGlobalVariableActionWidget::VariableElement &var)
 {
-    SieveActionWidget *w = qobject_cast<SieveActionWidget *>(widgets().constLast());
+    auto *w = qobject_cast<SieveActionWidget *>(widgets().constLast());
     if (w->isConfigurated()) {
         addWidgetAfterThisWidget(widgets().constLast());
         w = qobject_cast<SieveActionWidget *>(widgets().constLast());
@@ -398,7 +385,7 @@ void SieveActionWidgetLister::loadScript(QXmlStreamReader &element, bool onlyAct
         if (tagName == QLatin1String("action")) {
             if (element.attributes().hasAttribute(QLatin1String("name"))) {
                 const QString actionName = element.attributes().value(QLatin1String("name")).toString();
-                SieveActionWidget *w = qobject_cast<SieveActionWidget *>(widgets().constLast());
+                auto *w = qobject_cast<SieveActionWidget *>(widgets().constLast());
                 if (w->isConfigurated()) {
                     addWidgetAfterThisWidget(widgets().constLast());
                     w = qobject_cast<SieveActionWidget *>(widgets().constLast());
@@ -431,7 +418,7 @@ void SieveActionWidgetLister::loadScript(QXmlStreamReader &element, bool onlyAct
                     } else {
                         addWidgetAfterThisWidget(widgets().constLast());
                     }
-                    SieveActionWidget *w = qobject_cast<SieveActionWidget *>(widgets().constLast());
+                    auto *w = qobject_cast<SieveActionWidget *>(widgets().constLast());
                     w->setAction(actionName, element, comment, error);
                     comment.clear();
                 } else {
