@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveconditiondate.h"
 #include "autocreatescripts/commonwidgets/selectmatchtypecombobox.h"
@@ -39,27 +26,27 @@ SieveConditionDate::SieveConditionDate(SieveEditorGraphicalModeWidget *sieveGrap
 QWidget *SieveConditionDate::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
-    QHBoxLayout *lay = new QHBoxLayout;
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto *lay = new QHBoxLayout;
+    lay->setContentsMargins({});
     w->setLayout(lay);
 
-    SelectMatchTypeComboBox *matchTypeCombo = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
+    auto *matchTypeCombo = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
     matchTypeCombo->setObjectName(QStringLiteral("matchtype"));
     connect(matchTypeCombo, &SelectMatchTypeComboBox::valueChanged, this, &SieveConditionDate::valueChanged);
     lay->addWidget(matchTypeCombo);
 
-    QGridLayout *grid = new QGridLayout;
-    grid->setContentsMargins(0, 0, 0, 0);
+    auto *grid = new QGridLayout;
+    grid->setContentsMargins({});
     lay->addLayout(grid);
     QLabel *lab = new QLabel(i18n("header:"));
     grid->addWidget(lab, 0, 0);
 
-    QLineEdit *header = new QLineEdit;
+    auto *header = new QLineEdit;
     connect(header, &QLineEdit::textChanged, this, &SieveConditionDate::valueChanged);
     header->setObjectName(QStringLiteral("header"));
     grid->addWidget(header, 0, 1);
 
-    SelectDateWidget *dateWidget = new SelectDateWidget;
+    auto *dateWidget = new SelectDateWidget;
     connect(dateWidget, &SelectDateWidget::valueChanged, this, &SieveConditionDate::valueChanged);
     dateWidget->setObjectName(QStringLiteral("datewidget"));
     grid->addWidget(dateWidget, 1, 0, 1, 2);
@@ -104,7 +91,7 @@ QString SieveConditionDate::help() const
     return i18n("The date test matches date/time information derived from headers containing date-time values.");
 }
 
-bool SieveConditionDate::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool notCondition, QString &error)
+void SieveConditionDate::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool notCondition, QString &error)
 {
     int index = 0;
     QString type;
@@ -126,7 +113,7 @@ bool SieveConditionDate::setParamWidgetValue(QXmlStreamReader &element, QWidget
             }
             ++index;
         } else if (tagName == QLatin1String("tag")) {
-            SelectMatchTypeComboBox *selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
+            auto *selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
             selectMatchCombobox->setCode(AutoCreateScriptUtil::tagValueWithCondition(element.readElementText(), notCondition), name(), error);
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
@@ -142,12 +129,10 @@ bool SieveConditionDate::setParamWidgetValue(QXmlStreamReader &element, QWidget
         setComment(commentStr);
     }
 
-    SelectDateWidget *dateWidget = w->findChild<SelectDateWidget *>(QStringLiteral("datewidget"));
+    auto *dateWidget = w->findChild<SelectDateWidget *>(QStringLiteral("datewidget"));
     dateWidget->setCode(type, value);
-    QLineEdit *header = w->findChild<QLineEdit *>(QStringLiteral("header"));
+    auto *header = w->findChild<QLineEdit *>(QStringLiteral("header"));
     header->setText(headerStr);
-
-    return true;
 }
 
 QUrl SieveConditionDate::href() const
