@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveconditionhasflag.h"
 #include "autocreatescripts/commonwidgets/selectmatchtypecombobox.h"
@@ -41,16 +28,16 @@ SieveConditionHasFlag::SieveConditionHasFlag(SieveEditorGraphicalModeWidget *sie
 QWidget *SieveConditionHasFlag::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
-    QHBoxLayout *lay = new QHBoxLayout;
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto *lay = new QHBoxLayout;
+    lay->setContentsMargins({});
     w->setLayout(lay);
-    SelectMatchTypeComboBox *selecttype = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
+    auto *selecttype = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
     selecttype->setObjectName(QStringLiteral("matchtype"));
     connect(selecttype, &SelectMatchTypeComboBox::valueChanged, this, &SieveConditionHasFlag::valueChanged);
     lay->addWidget(selecttype);
 
-    QGridLayout *grid = new QGridLayout;
-    grid->setContentsMargins(0, 0, 0, 0);
+    auto *grid = new QGridLayout;
+    grid->setContentsMargins({});
     lay->addLayout(grid);
 
     int row = 0;
@@ -58,7 +45,7 @@ QWidget *SieveConditionHasFlag::createParamWidget(QWidget *parent) const
         QLabel *lab = new QLabel(i18n("Variable name\n (if empty it uses internal variable):"));
         grid->addWidget(lab, row, 0);
 
-        QLineEdit *variableName = new QLineEdit;
+        auto *variableName = new QLineEdit;
         variableName->setObjectName(QStringLiteral("variablename"));
         connect(variableName, &QLineEdit::textChanged, this, &SieveConditionHasFlag::valueChanged);
         grid->addWidget(variableName, row, 1);
@@ -145,7 +132,7 @@ void SieveConditionHasFlag::setParamWidgetValue(QXmlStreamReader &element, QWidg
     while (element.readNextStartElement()) {
         const QStringRef tagName = element.name();
         if (tagName == QLatin1String("tag")) {
-            SelectMatchTypeComboBox *matchTypeCombo = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
+            auto *matchTypeCombo = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
             matchTypeCombo->setCode(AutoCreateScriptUtil::tagValueWithCondition(element.readElementText(), notCondition), name(), error);
         } else if (tagName == QLatin1String("str")) {
             strList << element.readElementText();
@@ -166,15 +153,15 @@ void SieveConditionHasFlag::setParamWidgetValue(QXmlStreamReader &element, QWidg
     switch (strList.count()) {
     case 1:
     {
-        AbstractRegexpEditorLineEdit *value = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("value"));
+        auto *value = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("value"));
         value->setCode(strList.at(0));
         break;
     }
     case 2:
         if (hasVariableSupport) {
-            QLineEdit *variableName = w->findChild<QLineEdit *>(QStringLiteral("variablename"));
+            auto *variableName = w->findChild<QLineEdit *>(QStringLiteral("variablename"));
             variableName->setText(strList.at(0));
-            AbstractRegexpEditorLineEdit *value = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("value"));
+            auto *value = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("value"));
             value->setCode(strList.at(1));
         } else {
             qCDebug(LIBKSIEVE_LOG) << " SieveConditionHasFlag has not variable support";
