@@ -1,25 +1,11 @@
-/* Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+/* SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "sieveeditortextmodewidget.h"
 #include "templates/sievetemplatewidget.h"
 #include "autocreatescripts/autocreatescriptdialog.h"
-#include "editor/sieveinfowidget.h"
 #include "editor/sievetextedit.h"
 #include "editor/warningwidget/sieveeditorwarning.h"
 #include "editor/warningwidget/sieveeditorparsingmissingfeaturewarning.h"
@@ -29,13 +15,13 @@
 #include "scriptsparsing/xmlprintingscriptbuilder.h"
 #include "scriptsparsing/parsingresultdialog.h"
 
-#include "kpimtextedit/plaintexteditfindbar.h"
-#include "kpimtextedit/plaintexteditorwidget.h"
-#include "kpimtextedit/texttospeechwidget.h"
-#include "kpimtextedit/textgotolinewidget.h"
+#include <KPIMTextEdit/PlainTextEditFindBar>
+#include <KPIMTextEdit/PlainTextEditorWidget>
+#include <KPIMTextEdit/TextToSpeechWidget>
+#include <KPIMTextEdit/TextGotoLineWidget>
 #include "KSplitterCollapserButton"
 #include "webengine/sieveeditorhelphtmlwidget.h"
-#include "kpimtextedit/slidecontainer.h"
+#include <KPIMTextEdit/SlideContainer>
 
 #include <ksieve/parser.h>
 #include <ksieve/error.h>
@@ -44,6 +30,7 @@
 #include <KLocalizedString>
 #include <KSharedConfig>
 #include <KConfigGroup>
+#include <KMessageBox>
 
 #include <QSplitter>
 #include <QShortcut>
@@ -62,8 +49,8 @@ using namespace KSieveUi;
 SieveEditorTextModeWidget::SieveEditorTextModeWidget(QWidget *parent)
     : SieveEditorAbstractWidget(parent)
 {
-    QVBoxLayout *lay = new QVBoxLayout(this);
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto *lay = new QVBoxLayout(this);
+    lay->setContentsMargins({});
 
     mMainSplitter = new QSplitter;
     mMainSplitter->setOrientation(Qt::Vertical);
@@ -74,22 +61,13 @@ SieveEditorTextModeWidget::SieveEditorTextModeWidget(QWidget *parent)
     //
     mSieveTemplateWidget = new SieveTemplateWidget(i18n("Sieve Template:"));
 
-    mSieveInfo = new SieveInfoWidget;
-
-    mExtraSplitter = new QSplitter;
-    mExtraSplitter->setOrientation(Qt::Vertical);
-
-    mExtraSplitter->addWidget(mSieveTemplateWidget);
-    mExtraSplitter->addWidget(mSieveInfo);
-    mExtraSplitter->setChildrenCollapsible(false);
-
     QWidget *textEditWidget = new QWidget;
-    QVBoxLayout *textEditLayout = new QVBoxLayout;
-    textEditLayout->setContentsMargins(0, 0, 0, 0);
+    auto *textEditLayout = new QVBoxLayout;
+    textEditLayout->setContentsMargins({});
 
     mEditorWidget = new QWidget;
-    QVBoxLayout *editorWidgetLayout = new QVBoxLayout;
-    editorWidgetLayout->setContentsMargins(0, 0, 0, 0);
+    auto *editorWidgetLayout = new QVBoxLayout;
+    editorWidgetLayout->setContentsMargins({});
     mEditorWidget->setLayout(editorWidgetLayout);
 
     mTabWidget = new SieveEditorTabWidget;
@@ -106,6 +84,8 @@ SieveEditorTextModeWidget::SieveEditorTextModeWidget(QWidget *parent)
     textEditLayout->addWidget(mTabWidget);
     connect(mTextEdit, &SieveTextEdit::openHelp, mTabWidget, &SieveEditorTabWidget::slotAddHelpPage);
     connect(mTextEdit, &SieveTextEdit::say, mTextToSpeechWidget, &KPIMTextEdit::TextToSpeechWidget::say);
+    connect(mTextEdit, &SieveTextEdit::editRule, this, &SieveEditorTextModeWidget::slotEditRule);
+    connect(mTextEdit, &SieveTextEdit::insertRule, this, &SieveEditorTextModeWidget::slotInsertRule);
 
     mGotoLineSliderContainer = new KPIMTextEdit::SlideContainer(this);
     mGoToLine = new KPIMTextEdit::TextGoToLineWidget;
@@ -135,9 +115,9 @@ SieveEditorTextModeWidget::SieveEditorTextModeWidget(QWidget *parent)
     textEditWidget->setLayout(textEditLayout);
 
     mTemplateSplitter->addWidget(textEditWidget);
-    mTemplateSplitter->addWidget(mExtraSplitter);
+    mTemplateSplitter->addWidget(mSieveTemplateWidget);
     mTemplateSplitter->setCollapsible(0, false);
-    new KSplitterCollapserButton(mExtraSplitter, mTemplateSplitter);
+    new KSplitterCollapserButton(mSieveTemplateWidget, mTemplateSplitter);
 
     connect(mSieveTemplateWidget, &SieveTemplateWidget::insertTemplate, mTextEdit, &SieveTextEdit::insertPlainText);
 
@@ -173,10 +153,14 @@ void SieveEditorTextModeWidget::writeConfig()
 {
     KConfigGroup group(KSharedConfig::openConfig(), "SieveEditor");
     group.writeEntry("mainSplitter", mMainSplitter->sizes());
-    group.writeEntry("extraSplitter", mExtraSplitter->sizes());
     group.writeEntry("templateSplitter", mTemplateSplitter->sizes());
 }
 
+QStringList SieveEditorTextModeWidget::sieveCapabilities() const
+{
+    return mSieveCapabilities;
+}
+
 SieveEditorTabWidget *SieveEditorTextModeWidget::tabWidget() const
 {
     return mTabWidget;
@@ -188,7 +172,6 @@ void SieveEditorTextModeWidget::readConfig()
     const QList<int> size = {400, 100};
 
     mMainSplitter->setSizes(group.readEntry("mainSplitter", size));
-    mExtraSplitter->setSizes(group.readEntry("extraSplitter", size));
     mTemplateSplitter->setSizes(group.readEntry("templateSplitter", size));
 }
 
@@ -230,6 +213,72 @@ void SieveEditorTextModeWidget::generateXml()
     delete dlg;
 }
 
+void SieveEditorTextModeWidget::slotEditRule(const QString &selectedText)
+{
+    const QByteArray script = selectedText.toUtf8();
+    KSieve::Parser parser(script.begin(),
+                          script.begin() + script.length());
+    KSieveUi::XMLPrintingScriptBuilder psb(2);
+    parser.setScriptBuilder(&psb);
+    const bool result = parser.parse();
+    if (result) {
+        QPointer<AutoCreateScriptDialog> dlg = new AutoCreateScriptDialog(this);
+        dlg->setSieveCapabilities(mSieveCapabilities);
+        dlg->setSieveImapAccountSettings(mSieveImapAccountSettings);
+        dlg->setListOfIncludeFile(mListOfIncludeFile);
+        QString error;
+        //qDebug() << " psb.result()" << psb.result();
+        dlg->loadScript(psb.result(), error);
+        if (dlg->exec()) {
+            QStringList requireModules;
+            const QString newScript = dlg->script(requireModules);
+            const QStringList needToAddRequire = insertNecessaryRequires(requireModules);
+            mTextEdit->insertPlainText(newScript);
+            insertRequires(needToAddRequire);
+        }
+        delete dlg;
+    } else {
+        KMessageBox::error(this, i18n("Selected text is not a full sieve script"), i18n("Parsing error"));
+    }
+}
+
+void SieveEditorTextModeWidget::insertRequires(const QStringList &needToAddRequire)
+{
+    if (!needToAddRequire.isEmpty()) {
+        QTextCursor textCursor = mTextEdit->textCursor();
+        textCursor.movePosition(QTextCursor::MoveOperation::Start);
+        textCursor.insertText(needToAddRequire.join(QLatin1Char('\n')) + QLatin1Char('\n'));
+    }
+}
+
+QStringList SieveEditorTextModeWidget::insertNecessaryRequires(const QStringList &requireModules)
+{
+    QStringList needToAddRequire;
+    const QString plainText = mTextEdit->toPlainText();
+    for (const QString &module : qAsConst(requireModules)) {
+        if (!plainText.contains(module)) {
+            needToAddRequire.append(module);
+        }
+    }
+    return needToAddRequire;
+}
+
+void SieveEditorTextModeWidget::slotInsertRule()
+{
+    QPointer<AutoCreateScriptDialog> dlg = new AutoCreateScriptDialog(this);
+    dlg->setSieveCapabilities(mSieveCapabilities);
+    dlg->setSieveImapAccountSettings(mSieveImapAccountSettings);
+    dlg->setListOfIncludeFile(mListOfIncludeFile);
+    if (dlg->exec()) {
+        QStringList requireModules;
+        const QString newScript = dlg->script(requireModules);
+        const QStringList needToAddRequire = insertNecessaryRequires(requireModules);
+        mTextEdit->insertPlainText(newScript);
+        insertRequires(needToAddRequire);
+    }
+    delete dlg;
+}
+
 void SieveEditorTextModeWidget::createRulesGraphically()
 {
     QPointer<AutoCreateScriptDialog> dlg = new AutoCreateScriptDialog(this);
@@ -237,11 +286,12 @@ void SieveEditorTextModeWidget::createRulesGraphically()
     dlg->setSieveImapAccountSettings(mSieveImapAccountSettings);
     dlg->setListOfIncludeFile(mListOfIncludeFile);
     if (dlg->exec()) {
-        QString requireModules;
+        QStringList requireModules;
         const QString script = dlg->script(requireModules);
+        const QStringList needToAddRequire = insertNecessaryRequires(requireModules);
         QString newPlainText = mTextEdit->toPlainText() + script;
-        if (!requireModules.isEmpty()) {
-            newPlainText.prepend(requireModules + QLatin1Char('\n'));
+        if (!needToAddRequire.isEmpty()) {
+            newPlainText.prepend(requireModules.join(QLatin1Char('\n')) + QLatin1Char('\n'));
         }
         mTextEdit->selectAll();
 
@@ -297,7 +347,7 @@ void SieveEditorTextModeWidget::copy()
     QWidget *w = mTabWidget->currentWidget();
     if (w == mEditorWidget) {
         mTextEdit->copy();
-    } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+    } else if (auto *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         page->copy();
     }
 }
@@ -307,7 +357,7 @@ void SieveEditorTextModeWidget::selectAll()
     QWidget *w = mTabWidget->currentWidget();
     if (w == mEditorWidget) {
         mTextEdit->selectAll();
-    } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+    } else if (auto *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         page->selectAll();
     }
 }
@@ -335,7 +385,7 @@ bool SieveEditorTextModeWidget::hasSelection() const
     QWidget *w = mTabWidget->currentWidget();
     if (w == mEditorWidget) {
         return mTextEdit->textCursor().hasSelection();
-    } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+    } else if (auto *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         return page->hasSelection();
     }
     return false;
@@ -346,7 +396,7 @@ void SieveEditorTextModeWidget::zoomIn()
     QWidget *w = mTabWidget->currentWidget();
     if (w == mEditorWidget) {
         mTextEdit->zoomIn();
-    } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+    } else if (auto *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         page->zoomIn();
     }
 }
@@ -356,7 +406,7 @@ void SieveEditorTextModeWidget::zoomOut()
     QWidget *w = mTabWidget->currentWidget();
     if (w == mEditorWidget) {
         mTextEdit->zoomOut();
-    } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+    } else if (auto *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         page->zoomOut();
     }
 }
@@ -409,7 +459,7 @@ void SieveEditorTextModeWidget::zoomReset()
     QWidget *w = mTabWidget->currentWidget();
     if (w == mEditorWidget) {
         mTextEdit->slotZoomReset();
-    } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+    } else if (auto *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         page->resetZoom();
     }
 }
@@ -425,7 +475,7 @@ void SieveEditorTextModeWidget::slotFind()
         mFindBar->showFind();
         mSliderContainer->slideIn();
         mFindBar->focusAndSetCursor();
-    } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+    } else if (auto *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         page->find();
     }
 }
@@ -488,7 +538,6 @@ void SieveEditorTextModeWidget::setSieveCapabilities(const QStringList &capabili
     mSieveCapabilities = capabilities;
     mTextEdit->setSieveCapabilities(mSieveCapabilities);
     mSieveTemplateWidget->setSieveCapabilities(mSieveCapabilities);
-    mSieveInfo->setServerInfo(capabilities);
 }
 
 void SieveEditorTextModeWidget::showEditorWarning()
