@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef SIEVESCRIPTDEBUGGERFRONTENDWIDGET_H
@@ -28,7 +15,7 @@ class PlainTextEditorWidget;
 }
 class KUrlRequester;
 class QProcess;
-class KLineEdit;
+class QLineEdit;
 class QSplitter;
 namespace KSieveUi {
 class SieveTextEditWidget;
@@ -40,11 +27,11 @@ public:
     explicit SieveScriptDebuggerFrontEndWidget(QWidget *parent = nullptr);
     ~SieveScriptDebuggerFrontEndWidget();
 
-    QString script() const;
+    Q_REQUIRED_RESULT QString script() const;
     void setScript(const QString &script);
-    bool canAccept() const;
+    Q_REQUIRED_RESULT bool canAccept() const;
 
-    QList<int> splitterSizes() const;
+    Q_REQUIRED_RESULT QList<int> splitterSizes() const;
     void setSplitterSizes(const QList<int> &sizes);
 
 Q_SIGNALS:
@@ -67,7 +54,7 @@ private:
     KPIMTextEdit::PlainTextEditorWidget *mSieveTestResult = nullptr;
     KUrlRequester *mEmailPath = nullptr;
     QProcess *mProcess = nullptr;
-    KLineEdit *mExtension = nullptr;
+    QLineEdit *mExtension = nullptr;
     QSplitter *mSplitter = nullptr;
 };
 }
