@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "utilmethodtest.h"
@@ -99,7 +86,7 @@ void UtilMethodTest::shouldAssignValue_data()
         info1.sieveImapAccountSettings.setUserName(userName);
         info1.sieveImapAccountSettings.setPassword(password);
 
-        info1.sieveImapAccountSettings.setAuthenticationType(KSieveUi::SieveImapAccountSettings::CramMD5);
+        info1.sieveImapAccountSettings.setAuthenticationType(KSieveUi::SieveImapAccountSettings::Plain);
         //TODO fix encryptionmode
         info1.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::Unencrypted);
 
@@ -139,7 +126,7 @@ void UtilMethodTest::shouldAssignValue_data()
         info1.sieveImapAccountSettings.setUserName(userName);
         info1.sieveImapAccountSettings.setPassword(password);
 
-        info1.sieveImapAccountSettings.setAuthenticationType(KSieveUi::SieveImapAccountSettings::Login);
+        info1.sieveImapAccountSettings.setAuthenticationType(KSieveUi::SieveImapAccountSettings::ClearText);
         //TODO fix encryptionmode
         info1.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::Unencrypted);
 
@@ -178,9 +165,9 @@ void UtilMethodTest::shouldAssignValue_data()
         info1.sieveImapAccountSettings.setUserName(userName);
         info1.sieveImapAccountSettings.setPassword(password);
 
-        info1.sieveImapAccountSettings.setAuthenticationType(KSieveUi::SieveImapAccountSettings::Login);
+        info1.sieveImapAccountSettings.setAuthenticationType(KSieveUi::SieveImapAccountSettings::ClearText);
         //TODO fix encryptionmode
-        info1.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::AnySslVersion);
+        info1.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::SSLorTLS);
 
         QTest::newRow("sievereuseconfig2ssl") << data1 << info1 << true << true;
     }
@@ -218,9 +205,9 @@ void UtilMethodTest::shouldAssignValue_data()
         info1.sieveImapAccountSettings.setUserName(userName);
         info1.sieveImapAccountSettings.setPassword(password);
 
-        info1.sieveImapAccountSettings.setAuthenticationType(KSieveUi::SieveImapAccountSettings::Login);
+        info1.sieveImapAccountSettings.setAuthenticationType(KSieveUi::SieveImapAccountSettings::ClearText);
         //TODO fix encryptionmode
-        info1.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::TlsV1);
+        info1.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::STARTTLS);
 
         QTest::newRow("sievereuseconfig2startls") << data1 << info1 << true << true;
     }
@@ -287,7 +274,7 @@ void UtilMethodTest::shouldAssignValue_data()
         info1.sieveImapAccountSettings.setUserName(imapUser);
         info1.sieveImapAccountSettings.setPassword(imapPasswd);
 
-        info1.sieveImapAccountSettings.setAuthenticationType(KSieveUi::SieveImapAccountSettings::DigestMD5);
+        info1.sieveImapAccountSettings.setAuthenticationType(KSieveUi::SieveImapAccountSettings::CramMD5);
 
         info1.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::Unencrypted);
 
@@ -328,7 +315,7 @@ void UtilMethodTest::shouldAssignValue_data()
         info1.sieveImapAccountSettings.setUserName(imapUser);
         info1.sieveImapAccountSettings.setPassword(imapPasswd);
 
-        info1.sieveImapAccountSettings.setAuthenticationType(KSieveUi::SieveImapAccountSettings::DigestMD5);
+        info1.sieveImapAccountSettings.setAuthenticationType(KSieveUi::SieveImapAccountSettings::CramMD5);
 
         info1.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::Unencrypted);
 
@@ -370,9 +357,9 @@ void UtilMethodTest::shouldAssignValue_data()
         info1.sieveImapAccountSettings.setUserName(imapUser);
         info1.sieveImapAccountSettings.setPassword(imapPasswd);
 
-        info1.sieveImapAccountSettings.setAuthenticationType(KSieveUi::SieveImapAccountSettings::DigestMD5);
+        info1.sieveImapAccountSettings.setAuthenticationType(KSieveUi::SieveImapAccountSettings::CramMD5);
 
-        info1.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::AnySslVersion);
+        info1.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::SSLorTLS);
 
         QTest::newRow("sievereusecustomconfig1withoutvacationfileSSL") << data1 << info1 << true << false;
     }
@@ -412,9 +399,9 @@ void UtilMethodTest::shouldAssignValue_data()
         info1.sieveImapAccountSettings.setUserName(imapUser);
         info1.sieveImapAccountSettings.setPassword(imapPasswd);
 
-        info1.sieveImapAccountSettings.setAuthenticationType(KSieveUi::SieveImapAccountSettings::DigestMD5);
+        info1.sieveImapAccountSettings.setAuthenticationType(KSieveUi::SieveImapAccountSettings::CramMD5);
 
-        info1.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::TlsV1);
+        info1.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::STARTTLS);
 
         QTest::newRow("sievereusecustomconfig1withoutvacationfileStarttls") << data1 << info1 << true << false;
     }
@@ -454,9 +441,9 @@ void UtilMethodTest::shouldAssignValue_data()
         info1.sieveImapAccountSettings.setUserName(imapUser);
         info1.sieveImapAccountSettings.setPassword(imapPasswd);
 
-        info1.sieveImapAccountSettings.setAuthenticationType(KSieveUi::SieveImapAccountSettings::GSSAPI);
+        info1.sieveImapAccountSettings.setAuthenticationType(KSieveUi::SieveImapAccountSettings::DigestMD5);
 
-        info1.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::TlsV1);
+        info1.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::STARTTLS);
 
         QTest::newRow("sievereusecustomconfig1withoutvacationfileStarttls2") << data1 << info1 << true << false;
     }
@@ -495,9 +482,9 @@ void UtilMethodTest::shouldAssignValue_data()
         info1.sieveImapAccountSettings.setUserName(imapUser);
         info1.sieveImapAccountSettings.setPassword(imapPasswd);
 
-        info1.sieveImapAccountSettings.setAuthenticationType(KSieveUi::SieveImapAccountSettings::GSSAPI);
+        info1.sieveImapAccountSettings.setAuthenticationType(KSieveUi::SieveImapAccountSettings::DigestMD5);
 
-        info1.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::TlsV1);
+        info1.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::STARTTLS);
 
         QTest::newRow("sievereusecustomconfig1withoutvacationfileStarttls3") << data1 << info1 << true << false;
     }
@@ -521,8 +508,8 @@ void UtilMethodTest::shouldAssignValue_data()
         data1.sieveVacationFilename = QStringLiteral("vacation.siv");
         data1.safety = QStringLiteral("STARTTLS");
         data1.alternateAuthentication = 4;
-        //MailTransport::Transport::EnumAuthenticationType::PLAIN = 0
-        data1.authentication = 0;
+        //MailTransport::Transport::EnumAuthenticationType::PLAIN = 2
+        data1.authentication = 2;
         data1.sieveAlternateUrl = QStringLiteral("bla.bla.com");
         data1.password = imapPasswd;
         data1.sieveCustomPassword = sievePasswd;
@@ -545,7 +532,12 @@ void UtilMethodTest::shouldAssignValue()
     std::unique_ptr<DataImapPasswordProvider> provider(new DataImapPasswordProvider(&data));
     const KSieveUi::Util::AccountInfo info = KSieveUi::Util::findAccountInfo(QStringLiteral("foo"), provider.get(), useVacationFile, interface);
     QCOMPARE(info.sieveImapAccountSettings.isValid(), sieveImapAccountValid);
-    QCOMPARE(info, accountInfo);
+    const bool equal = (info == accountInfo);
+    if (!equal) {
+        qDebug() << " info " << info;
+        qDebug() << " accountInfo " << accountInfo;
+    }
+    QVERIFY(equal);
 }
 
 QTEST_MAIN(UtilMethodTest)
