@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef SIEVEIMAPACCOUNTSETTINGS_H
@@ -33,22 +20,21 @@ public:
     //Keep sync with KIMAP settings.
     enum EncryptionMode {
         Unencrypted = 0,
-        TlsV1,
-        SslV2,
-        SslV3,
-        SslV3_1,
-        AnySslVersion
+        SSLorTLS, /*!< Use SSL/TLS encryption, KIMAP will automatically negoatiate
+                       the best supported encryption protocol. */
+        STARTTLS  /*!< Use STARTTLS to upgrade an initially plaintext connection to
+                       encrypted connection. KIMAP will automatically negoatiate
+                       the best supported encryption protocol. */
     };
 
     enum AuthenticationMode {
-        Login = 0,
+        ClearText = 0,
+        Login,
         Plain,
         CramMD5,
         DigestMD5,
-        GSSAPI,
         NTLM,
-        APOP,
-        ClearText,
+        GSSAPI,
         Anonymous,
         XOAuth2
     };
