@@ -1,20 +1,7 @@
 /*
- * Copyright (c) 2015 Sandro Knauß <knauss@kolabsys.com>
+ * SPDX-FileCopyrightText: 2015 Sandro Knauß <knauss@kolabsys.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "vacationutilstest.h"
@@ -70,7 +57,7 @@ void VacationUtilsTest::testParseActivate_data()
 
     QTest::newRow("notfound") << QStringLiteral("vacation-notfound.siv") << false << false;
     QTest::newRow("simple") << QStringLiteral("vacation-simple.siv") << true << true;
-    QTest::newRow("multile if") << QStringLiteral("vacation-multiple.siv") << true << true;
+    QTest::newRow("multiple if") << QStringLiteral("vacation-multiple.siv") << true << true;
     QTest::newRow("deactivate") << QStringLiteral("vacation-deactivate.siv") << true << false;
     QTest::newRow("deactivate-multiple if") << QStringLiteral("vacation-deactivate-multiple.siv") << true << false;
     QTest::newRow("deactivate-complex") << QStringLiteral("vacation-deactivate-complex.siv") << true << false;
@@ -299,8 +286,8 @@ void VacationUtilsTest::testUpdateVacationBlock()
 
     const QString attend = QStringLiteral("if true\n{\ntestcmd;\n}\n");
     const QString require = QStringLiteral("require [\"date\", \"test\"];");
-    const QString scriptAattend = scriptA + QStringLiteral("\n") + attend;
-    const QString scriptBattend = scriptB + QStringLiteral("\n") + attend;
+    const QString scriptAattend = scriptA + QLatin1Char('\n') + attend;
+    const QString scriptBattend = scriptB + QLatin1Char('\n') + attend;
 
     QStringList linesA = scriptA.split(QLatin1Char('\n'));
     QStringList header;
