@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "multiimapvacationdialog.h"
@@ -56,7 +43,7 @@ MultiImapVacationDialog::MultiImapVacationDialog(MultiImapVacationManager *manag
 {
     d->mVacationManager = manager;
 
-    setWindowTitle(i18n("Configure \"Out of Office\" Replies"));
+    setWindowTitle(i18nc("@title:window", "Configure \"Out of Office\" Replies"));
     init();
     readConfig();
 }
@@ -82,14 +69,14 @@ void MultiImapVacationDialog::reject()
 {
     bool canCloseDialog = true;
     for (int i = 0; i < d->mTabWidget->count(); ++i) {
-        VacationPageWidget *vacationPage = qobject_cast<VacationPageWidget *>(d->mTabWidget->widget(i));
+        auto *vacationPage = qobject_cast<VacationPageWidget *>(d->mTabWidget->widget(i));
         if (vacationPage) {
             if (vacationPage->wasChanged()) {
                 if (KMessageBox::questionYesNo(
-                            this,
-                            i18nc("@info", "Do you really want to cancel?"),
-                            i18nc("@title:window", "Confirmation")) == KMessageBox::Yes) {
-                        QDialog::reject(); // Discard current changes
+                        this,
+                        i18nc("@info", "Do you really want to cancel?"),
+                        i18nc("@title:window", "Confirmation")) == KMessageBox::Yes) {
+                    QDialog::reject();     // Discard current changes
                 }
                 canCloseDialog = false;
                 break;
@@ -109,13 +96,13 @@ QVector<VacationCreateScriptJob *> MultiImapVacationDialog::listCreateJob() cons
 void MultiImapVacationDialog::init()
 {
     d->mStackedWidget = new QStackedWidget;
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(d->mStackedWidget);
     d->mTabWidget = new QTabWidget;
     d->mStackedWidget->addWidget(d->mTabWidget);
 
     QWidget *w = new QWidget;
-    QVBoxLayout *vbox = new QVBoxLayout;
+    auto *vbox = new QVBoxLayout;
     w->setLayout(vbox);
     QLabel *lab = new QLabel(i18n("KMail's Out of Office Reply functionality relies on "
                                   "server-side filtering. You have not yet configured an "
@@ -169,7 +156,7 @@ void MultiImapVacationDialog::slotCanceled()
 
 void MultiImapVacationDialog::createPage(const QString &serverName, const KSieveUi::Util::AccountInfo &info)
 {
-    VacationPageWidget *page = new VacationPageWidget;
+    auto *page = new VacationPageWidget;
     page->setServerUrl(info.sieveUrl);
     page->setServerName(serverName);
     page->setVacationManager(d->mVacationManager);
@@ -200,7 +187,7 @@ void MultiImapVacationDialog::slotOkClicked()
     qDeleteAll(d->mListCreateJob);
     d->mListCreateJob.clear();
     for (int i = 0; i < d->mTabWidget->count(); ++i) {
-        VacationPageWidget *vacationPage = qobject_cast<VacationPageWidget *>(d->mTabWidget->widget(i));
+        auto *vacationPage = qobject_cast<VacationPageWidget *>(d->mTabWidget->widget(i));
         if (vacationPage) {
             VacationCreateScriptJob *job = vacationPage->writeScript(errorFound);
 
@@ -223,7 +210,7 @@ void MultiImapVacationDialog::slotOkClicked()
 void MultiImapVacationDialog::slotDefaultClicked()
 {
     for (int i = 0; i < d->mTabWidget->count(); ++i) {
-        VacationPageWidget *vacationPage = qobject_cast<VacationPageWidget *>(d->mTabWidget->widget(i));
+        auto *vacationPage = qobject_cast<VacationPageWidget *>(d->mTabWidget->widget(i));
         if (vacationPage) {
             vacationPage->setDefault();
         }
