@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "multiimapvacationmanager.h"
@@ -60,7 +47,7 @@ void MultiImapVacationManager::checkVacation(const QString &serverName, const QU
 {
     ++mNumberOfJobs;
     if (!mKep14Support.contains(serverName)) {
-        CheckKolabKep14SupportJob *checkKep14Job = new CheckKolabKep14SupportJob(this);
+        auto *checkKep14Job = new CheckKolabKep14SupportJob(this);
         checkKep14Job->setProperty("triggerScript", true);
         checkKep14Job->setServerName(serverName);
         checkKep14Job->setServerUrl(url);
@@ -69,7 +56,7 @@ void MultiImapVacationManager::checkVacation(const QString &serverName, const QU
         return;
     }
 
-    VacationCheckJob *job = new VacationCheckJob(url, serverName, this);
+    auto *job = new VacationCheckJob(url, serverName, this);
     job->setKep14Support(mKep14Support[serverName]);
     connect(job, &VacationCheckJob::vacationScriptActive, this, &MultiImapVacationManager::slotScriptActive);
     job->start();
