@@ -1,18 +1,7 @@
 /*
-  Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "vacationcreatescriptjob.h"
@@ -182,7 +171,7 @@ void VacationCreateScriptJob::slotGotActiveScripts(ParseUserScriptJob *job)
     }
     mCreateJob = new GenerateGlobalScriptJob(mUrl, this);
     mCreateJob->addUserActiveScripts(list);
-    connect(mCreateJob, &GenerateGlobalScriptJob::success, [=]() {
+    connect(mCreateJob, &GenerateGlobalScriptJob::success, this, [=]() {
         this->slotGenerateDone();
     });
     connect(mCreateJob, &GenerateGlobalScriptJob::error, this, &VacationCreateScriptJob::slotGenerateDone);
