@@ -1,18 +1,7 @@
 /*
-  Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "vacationpagewidget.h"
@@ -37,15 +26,15 @@ using namespace KSieveUi;
 VacationPageWidget::VacationPageWidget(QWidget *parent)
     : QWidget(parent)
 {
-    QVBoxLayout *lay = new QVBoxLayout(this);
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto *lay = new QVBoxLayout(this);
+    lay->setContentsMargins({});
     mStackWidget = new QStackedWidget;
     lay->addWidget(mStackWidget);
 
     //Main Page
     QWidget *mainPage = new QWidget;
-    QVBoxLayout *vbox = new QVBoxLayout;
-    vbox->setContentsMargins(0, 0, 0, 0);
+    auto *vbox = new QVBoxLayout;
+    vbox->setContentsMargins({});
     mainPage->setLayout(vbox);
     mVacationWarningWidget = new VacationWarningWidget(this);
     vbox->addWidget(mVacationWarningWidget);
@@ -113,17 +102,17 @@ void VacationPageWidget::slotGetResult(const QString &serverName, const QStringL
     }
     qCDebug(LIBKSIEVE_LOG) << serverName << sieveCapabilities
                           #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-                           << endl
+        << endl
                           #else
-                           << Qt::endl
+        << Qt::endl
                           #endif
-                           << scriptName << "(" << active << ")"
+        << scriptName << "(" << active << ")"
                           #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-                           << endl
+        << endl
                           #else
-                           << Qt::endl
+        << Qt::endl
                           #endif
-                              ;
+    ;
 
     if (mUrl.scheme() == QLatin1String("sieve")
         && !sieveCapabilities.contains(QLatin1String("vacation"))) {
@@ -203,7 +192,7 @@ KSieveUi::VacationCreateScriptJob *VacationPageWidget::writeScript(bool &errorFo
             vacation.endTime = QTime();
         }
         const QString script = VacationUtils::composeScript(vacation);
-        KSieveUi::VacationCreateScriptJob *createJob = new KSieveUi::VacationCreateScriptJob;
+        auto *createJob = new KSieveUi::VacationCreateScriptJob;
         createJob->setServerUrl(mUrl);
         createJob->setServerName(mServerName);
         createJob->setStatus(active, mWasActive);
