@@ -1,18 +1,7 @@
 /*
-  Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "custommanagesievewidget.h"
@@ -54,7 +43,7 @@ bool CustomManageSieveWidget::refreshList()
         const KSieveUi::Util::AccountInfo info = KSieveUi::Util::fullAccountInfo(type.identifier(), mPasswordProvider, false);
         const QUrl u = info.sieveUrl;
         if (u.isEmpty()) {
-            QTreeWidgetItem *item = new QTreeWidgetItem(last);
+            auto *item = new QTreeWidgetItem(last);
             item->setText(0, i18n("No Sieve URL configured"));
             item->setFlags(item->flags() & ~Qt::ItemIsEnabled);
             treeView()->expandItem(last);
